summaryrefslogtreecommitdiff
path: root/mpn/x86/addmul_1.S
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/x86/addmul_1.S')
-rw-r--r--mpn/x86/addmul_1.S10
1 files changed, 5 insertions, 5 deletions
diff --git a/mpn/x86/addmul_1.S b/mpn/x86/addmul_1.S
index 5b808d3ee..0686066f9 100644
--- a/mpn/x86/addmul_1.S
+++ b/mpn/x86/addmul_1.S
@@ -1,4 +1,4 @@
/* x86 __mpn_addmul_1 (for 386 and 486) -- Multiply a limb vector
with a limb and add the result to a second limb vector.
Copyright (C) 1992, 1994, 1997, 1999, 2000 Free Software Foundation, Inc.
@@ -37,9 +37,9 @@ MA 02111-1307, USA. */
TEXT
ALIGN (3)
-PROLOGUE(C_SYMBOL_NAME(__mpn_addmul_1))
- GLOBL C_SYMBOL_NAME(__mpn_addmul_1)
-C_SYMBOL_NAME(__mpn_addmul_1:)
+PROLOGUE(C_SYMBOL_NAME(__gmpn_addmul_1))
+ GLOBL C_SYMBOL_NAME(__gmpn_addmul_1)
+C_SYMBOL_NAME(__gmpn_addmul_1:)
INSN1(push,l ,R(edi))
INSN1(push,l ,R(esi))
@@ -115,4 +115,4 @@ Lend: movl %ebx,%eax
INSN1(pop,l ,R(edi))
ret
-EPILOGUE(C_SYMBOL_NAME(__mpn_addmul_1))
+EPILOGUE(C_SYMBOL_NAME(__gmpn_addmul_1))
@@ -1,4 +1,4 @@
-/* x86 __mpn_addmul_1 (for 386 and 486) -- Multiply a limb vector
+/* x86 __gmpn_addmul_1 (for 386 and 486) -- Multiply a limb vector
with a limb and add the result to a second limb vector.
Copyright (C) 1992, 1994, 1997, 1999, 2000 Free Software Foundation, Inc.